#
# spec file for package argocd-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name argocd

Name:           argocd-cli
Version:        3.0.5
Release:        1.1
Summary:        CLI for the ArgoCD declarative continuous deployment tool
License:        Apache-2.0
URL:            https://github.com/argoproj/argo-cd
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  go >= 1.20
BuildRequires:  zsh

%description
Argo CD is a declarative, GitOps continuous delivery tool for Kubernetes.

This packages contains the CLI to interact with the ArgoCD installation in a
Kubernetes cluster.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
KUBECTL_VERSION=$(awk '/=> k8s.io\/kubectl v/ {print $4}' go.mod)

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="\
   -X github.com/argoproj/argo-cd/v2/common.version=%{version} \
   -X github.com/argoproj/argo-cd/v2/common.buildDate=${BUILD_DATE} \
   -X github.com/argoproj/argo-cd/v2/common.gitCommit=v%{version} \
   -X github.com/argoproj/argo-cd/v2/common.gitTag=v%{version} \
   -X github.com/argoproj/argo-cd/v2/common.gitTreeState=clean \
   -X github.com/argoproj/argo-cd/v2/common.kubectlVersion=${KUBECTL_VERSION}" \
   -o bin/%{executable_name} ./cmd/

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} "%{buildroot}/%{_bindir}/%{executable_name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Sat May 31 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.5:
  * Changelog
  - fe5869d: fix(hydrator): increase max msg size (cherry-pick
    [#23190]) (#23191) (@gcp-cherry-pick-bot[bot])
  - 0e20cb6: fix: add cooldown to prevent resetting autoheal exp
    backoff preemptively (cherry-pick #23057) (#23189)
    (@gdsoumya)
* Sat May 31 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.4:
  * Changelog
    This release fixes a critical security issue:
    GHSA-2hj5-g64g-fp6p
  * Other work
  - 040ed44: Merge commit from fork (@crenshaw-dev)
  - c27a9d3: fix(commit-server): apply image override
    (cherry-pick #22916) (#22917) (@gcp-cherry-pick-bot[bot])
* Thu May 22 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.3:
  No CLI-related changes in the changelog
* Tue May 20 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.2:
  No CLI-related changes in the changelog
* Thu May 15 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.1:
  No CLI-related changes in the changelog
* Thu May 15 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 3.0.0:
  Major upgrade with a very big changelog, see
  https://github.com/argoproj/argo-cd/releases/tag/v3.0.0
  * CLI-related changes
  - fix(cli): improve performance for admin export/import cmd
    (#22322)
  - fix(cli): log correct error message when updating a cluster
    that is not present (#22190)
  - docs: Adding Argo CD CLI plugin support proposal (#19624)
  - fix(cli): ignored resources should not be pruned during
    restore (#21894)
  - fix(cli): add flags to admin import for retrying updates on
    conflicts and skipping resources with specific labels.
    (#21694)
  - fix(cli): application cannot be refreshed when invalid and
    hangs (#21615)
  - fix(cli): use correct CA when adding kube-public clusters
    (#21326) (#21327)
  - fix(cli): wrong variable to store --no-proxy value (#21226)
  * Dependency updates
  - chore(deps): bump @types/selenium-webdriver from 4.1.27 to
    4.1.28 in /ui-test (#21414) (@dependabot[bot])
  - chore(deps): bump SonarSource/sonarqube-scan-action from
    4.1.0 to 4.2.1 (#21230) (@dependabot[bot])
  - chore(deps): bump axios from 1.7.4 to 1.8.2 in /ui-test
    (#22247) (@dependabot[bot])
  - chore(deps): bump bitnami/kubectl from 1.31 to 1.32 in
    /test/container (#21234) (@dependabot[bot])
  - chore(deps): bump chromedriver from 131.0.3 to 131.0.4 in
    /ui-test (#21268) (@dependabot[bot])
  - chore(deps): bump chromedriver from 131.0.4 to 131.0.5 in
    /ui-test (#21415) (@dependabot[bot])
  - chore(deps): bump chromedriver from 131.0.5 to 132.0.0 in
    /ui-test (#21512) (@dependabot[bot])
  - chore(deps): bump chromedriver from 132.0.0 to 132.0.1 in
    /ui-test (#21646) (@dependabot[bot])
  - chore(deps): bump chromedriver from 132.0.1 to 133.0.2 in
    /ui-test (#21916) (@dependabot[bot])
  - chore(deps): bump chromedriver from 133.0.2 to 133.0.3 in
    /ui-test (#22018) (@dependabot[bot])
  - chore(deps): bump chromedriver from 133.0.3 to 134.0.0 in
    /ui-test (#22218) (@dependabot[bot])
  - chore(deps): bump chromedriver from 134.0.0 to 134.0.2 in
    /ui-test (#22307) (@dependabot[bot])
  - chore(deps): bump code.gitea.io/sdk/gitea from 0.19.0 to
    0.20.0 (#21464) (@dependabot[bot])
  - chore(deps): bump docker/setup-buildx-action from 3.7.1 to
    3.8.0 (#21210) (@dependabot[bot])
  - chore(deps): bump
    github.com/Azure/azure-sdk-for-go/sdk/azidentity from 1.8.0
    to 1.8.1 (#21566) (@dependabot[bot])
  - chore(deps): bump
    github.com/Azure/azure-sdk-for-go/sdk/azidentity from 1.8.1
    to 1.8.2 (#21867) (@dependabot[bot])
  - chore(deps): bump github.com/Azure/kubelogin from 0.1.6 to
    0.1.8 (#22271) (@dependabot[bot])
  - chore(deps): bump github.com/Azure/kubelogin from 0.1.8 to
    0.1.9 (#22308) (@dependabot[bot])
  - chore(deps): bump github.com/alicebob/miniredis/v2 from
    2.33.0 to 2.34.0 (#21232) (@dependabot[bot])
  - chore(deps): bump github.com/aws/aws-sdk-go from 1.55.5 to
    1.55.6 (#21514) (@dependabot[bot])
  - chore(deps): bump github.com/bmatcuk/doublestar/v4 from 4.7.1
    to 4.8.0 (#21483) (@dependabot[bot])
  - chore(deps): bump github.com/bmatcuk/doublestar/v4 from 4.8.0
    to 4.8.1 (#21677) (@dependabot[bot])
  - chore(deps): bump github.com/bradleyfalzon/ghinstallation/v2
    (#21353) (@dependabot[bot])
  - chore(deps): bump github.com/bradleyfalzon/ghinstallation/v2
    from 2.13.0 to 2.14.0 (#21955) (@dependabot[bot])
  - chore(deps): bump github.com/casbin/casbin/v2 from 2.102.0 to
    2.103.0 (#21330) (@dependabot[bot])
  - chore(deps): bump github.com/casbin/govaluate from 1.2.0 to
    1.3.0 (#21331) (@dependabot[bot])
  - chore(deps): bump github.com/coreos/go-oidc/v3 from 3.11.0 to
    3.12.0 (#21383) (@dependabot[bot])
  - chore(deps): bump github.com/coreos/go-oidc/v3 from 3.12.0 to
    3.13.0 (#22347) (@dependabot[bot])
  - chore(deps): bump github.com/cyphar/filepath-securejoin
    (#21233) (@dependabot[bot])
  - chore(deps): bump github.com/cyphar/filepath-securejoin from
    0.3.6 to 0.4.0 (#21484) (@dependabot[bot])
  - chore(deps): bump github.com/cyphar/filepath-securejoin from
    0.4.0 to 0.4.1 (#21700) (@dependabot[bot])
  - chore(deps): bump github.com/dlclark/regexp2 from 1.11.4 to
    1.11.5 (#21853) (@dependabot[bot])
  - chore(deps): bump github.com/evanphx/json-patch from
    5.9.0+incompatible to 5.9.11+incompatible (#21699)
    (@dependabot[bot])
  - chore(deps): bump github.com/go-git/go-git/v5 from 5.12.0 to
    5.13.0 (#21329) (@dependabot[bot])
  - chore(deps): bump github.com/go-git/go-git/v5 from 5.13.0 to
    5.13.1 (#21352) (@dependabot[bot])
  - chore(deps): bump github.com/go-git/go-git/v5 from 5.13.1 to
    5.13.2 (#21641) (@dependabot[bot])
  - chore(deps): bump github.com/go-git/go-git/v5 from 5.13.2 to
    5.14.0 (#22076) (@dependabot[bot])
  - chore(deps): bump github.com/go-jose/go-jose/v3 to v4
    (#22154) (@nitishfy)
  - chore(deps): bump github.com/go-jose/go-jose/v4 from 4.0.2 to
    4.0.5 (#21989) (@dependabot[bot])
  - chore(deps): bump github.com/golang-jwt/jwt to 4.5.2/5.2.2
    (#22464) (@crenshaw-dev)
  - chore(deps): bump github.com/golang/glog from 1.2.2 to 1.2.4
    (#21693) (@dependabot[bot])
  - chore(deps): bump github.com/google/go-cmp from 0.6.0 to
    0.7.0 (#21956) (@dependabot[bot])
  - chore(deps): bump github.com/gosimple/slug from 1.14.0 to
    1.15.0 (#21304) (@dependabot[bot])
  - chore(deps): bump github.com/prometheus/client_golang from
    1.20.5 to 1.21.0 (#21915) (@dependabot[bot])
  - chore(deps): bump github.com/prometheus/client_golang from
    1.21.0 to 1.21.1 (#22180) (@dependabot[bot])
  - chore(deps): bump github.com/redis/go-redis/v9 from 9.7.0 to
    9.7.1 (#21957) (@dependabot[bot])
  - chore(deps): bump github.com/spf13/cobra from 1.8.1 to 1.9.1
    (#21889) (@dependabot[bot])
  - chore(deps): bump github.com/spf13/pflag from 1.0.5 to 1.0.6
    (#21717) (@dependabot[bot])
  - chore(deps): bump gitops-engine to latest (#22071)
    (@pjiang-dev)
  - chore(deps): bump gitpod/workspace-full from 230285e to
    bec45eb (#20980) (@dependabot[bot])
  - chore(deps): bump gitpod/workspace-full from bec45eb to
    a47a68e (#21843) (@dependabot[bot])
  - chore(deps): bump go 1.23.5 & tools (#21748) (@agaudreault)
  - chore(deps): bump go.opentelemetry.io/otel from 1.33.0 to
    1.34.0 (#21569) (@dependabot[bot])
  - chore(deps): bump go.opentelemetry.io/otel from 1.34.0 to
    1.35.0 (#22217) (@dependabot[bot])
  - chore(deps): bump go.opentelemetry.io/otel/sdk from 1.33.0 to
    1.34.0 (#21570) (@dependabot[bot])
  - chore(deps): bump golang.org/x/crypto from 0.31.0 to 0.32.0
    (#21397) (@dependabot[bot])
  - chore(deps): bump golang.org/x/crypto from 0.32.0 to 0.33.0
    (#21827) (@dependabot[bot])
  - chore(deps): bump golang.org/x/net from 0.32.0 to 0.33.0
    (#21254) (@dependabot[bot])
  - chore(deps): bump golang.org/x/net from 0.33.0 to 0.34.0
    (#21396) (@dependabot[bot])
  - chore(deps): bump golang.org/x/net from 0.35.0 to 0.36.0
    (#22182) (@dependabot[bot])
  - chore(deps): bump golang.org/x/net from 0.36.0 to 0.37.0
    (#22209) (@dependabot[bot])
  - chore(deps): bump golang.org/x/oauth2 from 0.24.0 to 0.25.0
    (#21384) (@dependabot[bot])
  - chore(deps): bump golang.org/x/oauth2 from 0.25.0 to 0.26.0
    (#21777) (@dependabot[bot])
  - chore(deps): bump golang.org/x/oauth2 from 0.26.0 to 0.27.0
    (#21990) (@dependabot[bot])
  - chore(deps): bump golang.org/x/oauth2 from 0.27.0 to 0.28.0
    (#22211) (@dependabot[bot])
  - chore(deps): bump golang.org/x/sync from 0.10.0 to 0.11.0
    (#21778) (@dependabot[bot])
  - chore(deps): bump golang.org/x/sync from 0.11.0 to 0.12.0
    (#22216) (@dependabot[bot])
  - chore(deps): bump golang.org/x/term from 0.27.0 to 0.28.0
    (#21382) (@dependabot[bot])
  - chore(deps): bump golang.org/x/term from 0.28.0 to 0.29.0
    (#21776) (@dependabot[bot])
  - chore(deps): bump golang.org/x/time from 0.10.0 to 0.11.0
    (#22212) (@dependabot[bot])
  - chore(deps): bump golang.org/x/time from 0.8.0 to 0.9.0
    (#21385) (@dependabot[bot])
  - chore(deps): bump golang.org/x/time from 0.9.0 to 0.10.0
    (#21779) (@dependabot[bot])
  - chore(deps): bump google.golang.org/grpc from 1.68.1 to
    1.69.0 (#21163) (@dependabot[bot])
  - chore(deps): bump google.golang.org/grpc from 1.69.0 to
    1.69.2 (#21270) (@dependabot[bot])
  - chore(deps): bump google.golang.org/grpc from 1.69.2 to
    1.69.4 (#21485) (@dependabot[bot])
  - chore(deps): bump google.golang.org/grpc from 1.69.4 to
    1.70.0 (#21657) (@dependabot[bot])
  - chore(deps): bump google.golang.org/grpc from 1.70.0 to
    1.71.0 (#22183) (@dependabot[bot])
  - chore(deps): bump google.golang.org/protobuf from 1.35.2 to
    1.36.0 (#21211) (@dependabot[bot])
  - chore(deps): bump google.golang.org/protobuf from 1.36.0 to
    1.36.1 (#21303) (@dependabot[bot])
  - chore(deps): bump google.golang.org/protobuf from 1.36.1 to
    1.36.2 (#21412) (@dependabot[bot])
  - chore(deps): bump google.golang.org/protobuf from 1.36.2 to
    1.36.3 (#21513) (@dependabot[bot])
  - chore(deps): bump google.golang.org/protobuf from 1.36.3 to
    1.36.4 (#21676) (@dependabot[bot])
  - chore(deps): bump google.golang.org/protobuf from 1.36.4 to
    1.36.5 (#21813) (@dependabot[bot])
  - chore(deps): bump jinja2 from 3.1.5 to 3.1.6 in /docs
    (#22219) (@dependabot[bot])
  - chore(deps): bump library/busybox from a5d0ce4 to 498a000 in
    /test/e2e/multiarch-container (#21959) (@dependabot[bot])
  - chore(deps): bump library/busybox in
    /test/e2e/multiarch-container (#21486) (@dependabot[bot])
  - chore(deps): bump library/golang from 1.23.4 to 1.23.5 in
    /test/remote (#21535) (@dependabot[bot])
  - chore(deps): bump library/golang from 1.23.5 to 1.23.6 in
    /test/container (#21774) (@dependabot[bot])
  - chore(deps): bump library/golang from 1.23.5 to 1.23.6 in
    /test/remote (#21799) (@dependabot[bot])
  - chore(deps): bump library/golang from 1.23.6 to 1.24.0 in
    /test/container (#21866) (@dependabot[bot])
  - chore(deps): bump library/golang from 1.23.6 to 1.24.0 in
    /test/remote (#21868) (@dependabot[bot])
  - chore(deps): bump library/golang from 1.24.0 to 1.24.1 in
    /test/remote (#22184) (@dependabot[bot])
  - chore(deps): bump library/golang from 2b1cbf2 to cd0c949 in
    /test/remote (#22020) (@dependabot[bot])
  - chore(deps): bump library/golang in /test/container (#21533)
    (@dependabot[bot])
  - chore(deps): bump library/redis from 7.4.1 to 7.4.2 in
    /test/container (#21395) (@dependabot[bot])
  - chore(deps): bump library/redis in /test/container (#20776)
    (@dependabot[bot])
  - chore(deps): bump library/redis in /test/container (#21253)
    (@dependabot[bot])
  - chore(deps): bump library/redis in /test/container (#21310)
    (@dependabot[bot])
  - chore(deps): bump library/redis in /test/container (#21494)
    (@dependabot[bot])
  - chore(deps): bump library/registry in /test/container
    (#20775) (@dependabot[bot])
  - chore(deps): bump selenium-webdriver from 4.27.0 to 4.29.0 in
    /ui-test (#22117) (@dependabot[bot])
  - chore(deps): bump sigs.k8s.io/controller-runtime from 0.19.3
    to 0.19.4 (#21411) (@dependabot[bot])
  - chore(deps): bump sigs.k8s.io/structured-merge-diff/v4 from
    4.4.4-0.20241211184406-7bf59b3d70ee to 4.6.0 (#22181)
    (@dependabot[bot])
  - chore(deps): switch to new expr package (#21982)
    (@crenshaw-dev)
  - chore(deps): update dependency gotestyourself/gotestsum to
    v1.12.0 (#21900) (@renovate[bot])
  - chore(deps): update dependency gotestyourself/gotestsum to
    v1.12.1 (#22328) (@renovate[bot])
  - chore(deps): update dependency jinja2 to v3.1.5 (#21289)
    (@renovate[bot])
  - chore(deps): update dependency pygments to v2.19.0 (#21379)
    (@renovate[bot])
  - chore(deps): update dependency pygments to v2.19.1 (#21392)
    (@renovate[bot])
  - chore(deps): update dependency pymdown-extensions to v10.13
    (#21301) (@renovate[bot])
  - chore(deps): update dependency pymdown-extensions to v10.14
    (#21403) (@renovate[bot])
  - chore(deps): update dependency pymdown-extensions to v10.14.3
    (#21619) (@renovate[bot])
  - chore(deps): update module github.com/golangci/golangci-lint
    to v1.63.2 (#21343) (@renovate[bot])
  - chore(deps): update module github.com/golangci/golangci-lint
    to v1.63.3 (#21348) (@renovate[bot])
  - chore(deps): update module github.com/golangci/golangci-lint
    to v1.63.4 (#21368) (@renovate[bot])
  - chore(deps): update module github.com/golangci/golangci-lint
    to v1.64.5 (#21850) (@renovate[bot])
  - chore(deps): update module github.com/golangci/golangci-lint
    to v1.64.6 (#22115) (@renovate[bot])
  - chore(deps): update module github.com/golangci/golangci-lint
    to v1.64.7 (#22306) (@renovate[bot])
  - chore(deps-dev): bump @types/mocha from 10.0.9 to 10.0.10 in
    /ui-test (#21251) (@dependabot[bot])
  - chore(deps-dev): bump @types/node from 22.10.10 to 22.13.4 in
    /ui-test (#21874) (@dependabot[bot])
  - chore(deps-dev): bump @types/node from 22.10.2 to 22.10.5 in
    /ui-test (#21381) (@dependabot[bot])
  - chore(deps-dev): bump @types/node from 22.10.5 to 22.10.6 in
    /ui-test (#21482) (@dependabot[bot])
  - chore(deps-dev): bump @types/node from 22.10.6 to 22.10.7 in
    /ui-test (#21511) (@dependabot[bot])
  - chore(deps-dev): bump @types/node from 22.10.7 to 22.10.8 in
    /ui-test (#21644) (@dependabot[bot])
  - chore(deps-dev): bump @types/node from 22.10.8 to 22.10.10 in
    /ui-test (#21658) (@dependabot[bot])
  - chore(deps-dev): bump @types/node from 22.13.4 to 22.13.5 in
    /ui-test (#21960) (@dependabot[bot])
  - chore(deps-dev): bump @types/node from 22.13.5 to 22.13.10 in
    /ui-test (#22272) (@dependabot[bot])
  - chore(deps-dev): bump @types/node from 22.9.3 to 22.10.2 in
    /ui-test (#21143) (@dependabot[bot])
  - chore(deps-dev): bump mocha from 10.7.3 to 11.0.1 in /ui-test
    (#21030) (@dependabot[bot])
  - chore(deps-dev): bump typescript from 5.7.2 to 5.7.3 in
    /ui-test (#21443) (@dependabot[bot])
  - chore(deps-dev): bump typescript from 5.7.3 to 5.8.2 in
    /ui-test (#22118) (@dependabot[bot])
* Thu Apr 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.14.11:
  No CLI-related changes in the changelog
* Wed Apr 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.14.10:
  * chore(deps): Update github.com/expr-lang/expr to v1.17.0 fixing
    CVE-2025-29786 (#22651)
  * fix(cli): wrong variable to store --no-proxy value (cherry-pick
    [#21226]) (#22590)
* Thu Apr  3 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.14.9:
  * - Bug fixes
    31a5545: fix: Check for semver constraint matching in
    application webhook handler (cherry-pick #21648) (#22508)
    (@gcp-cherry-pick-bot[bot])
  * Other work
  - c868711: chore(dep): bump gitops-engine 2.14 (#22520)
    (@pjiang-dev)
* Tue Mar 25 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.14.8:
  * Bug fixes
  - 9a9e62d: fix(server): fully populate app destination before
    project checks (#22408) (#22426) (@crenshaw-dev)
  - 7acdaa9: fix: CVE-2025-26791 upgrading redoc dep to 2.4.0 to
    avoid DOMPurify b… (#21997) (@nmirasch)
  - 872319e: fix: handle annotated git tags correctly in repo
    server cache (#21771) (#22424) (@aali309)
  * Dependency updates
  - 9f832cd: chore(deps): bump github.com/golang-jwt/jwt to
    4.5.2/5.2.2 (#22465) (@crenshaw-dev)
  * Other work
  - ec45e33: fix(ui, rbac): project-roles (#21829) (2.14
    backport) (#22461) (@blakepettersson)
* Wed Mar 19 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.14.7:
  * Bump version to 2.14.7 on release-2.14 branch (#22412)
  * chore(deps): bump gitops engine (#22405)
* Tue Mar 18 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.14.6:
  * chore(deps): Update go-git from 5.12.0 to 5.13.2 to include
    several CVE fixes (#22313)
* Tue Mar 11 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.14.5:
  * Bump version to 2.14.5 on release-2.14 branch (#22292)
  * chore(deps): bump github.com/redis/go-redis/v9 from 9.7.0 to
    9.7.1 (#21957) (#22255)
* Wed Mar  5 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.14.4:
  No CLI-related changes in the changelog
  Please note, the 2.14.3 release was yanked, 2.14.4 fixed all the
  regressions
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.14.2:
  * Bump version to 2.14.2 on release-2.14 branch (#21797)
  * fix: Add proxy registry key by dest server + name (cherry-pick
    [#21791]) (#21794)
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.14.1:
  * Bump version to 2.14.1 on release-2.14 branch (#21758)
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.14.0:
  Large update, please find the full changelog at
  https://github.com/argoproj/argo-cd/releases/tag/v2.14.0
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.13.5:
  * Bump version to 2.13.5 on release-2.13 branch (#21795)
  * fix: Add proxy registry key by dest server + name (cherry-pick
    [#21791]) (#21793)
  * fix(ui): Solve issue with navigating with dropdown from an
    application's page (cherry-pick #21737) (#21747)
* Thu Jan 30 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.13.4:
  * Bump version to 2.13.4 on release-2.13 branch (#21709)
  * Merge commit from fork
  * fix: oras-go client should fallback to docker config if no
    credentials specified (cherry-pick 2.13 #18133) (#20872)
  * fix: Policy/policy.open-cluster-management.io stuck in
    progressing status when no clusters match the policy (#21296)
    (cherry-pick #21297) (#21594)
  * docs: add mkdocs configuration stanza to .readthedocs.yaml
    (cherry-pick #21475) (#21609)
  * fix: resolve the failing e2e appset tests for ksonnet
    applications (cherry-pick #21580) (#21605)
  * fix: login return_url doesn't work with custom server paths
    (cherry-pick #21588) (#21603)
  * chore(deps): bump go-git version to go-git/v5 5.13.1 (#21551)
  * fix(appset): events not honouring configured namespaces
    (#21219) (#21241) (#21520)
  * Fix application url for custom base href (#21377) (#21515)
  * docs: Update Screenshot in Orphaned Resources Monitoring
    Section #20510 (cherry-pick #20533) (#21489)
  * chore(deps): bump github.com/go-git/go-git/v5 from 5.12.0 to
    5.13.0 (cherry-pick #21329) (#21401)
* Fri Jan  3 2025 opensuse_buildservice@ojkastl.de
- Update to version 2.13.3:
  * Bump version to 2.13.3 (#21359)
  * fix: Change applicationset generate HTTP method to avoid route
    conflicts (#20758) (#21300)
  * fix(ui): add optional check to avoid undefined reference in
    project detail (#20044) (#21263)
  * fix(appset): Fix appset generate in --core mode for cluster gen
    (#21170) (#21236)
  * fix(api): send to closed channel in mergeLogStreams (#7006)
    (#21178) (#21187)
  * fix: Populate destination name when destination server is
    specified (#21063) (cherry-pick 2.13) (#21176)
* Thu Dec 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.13.2:
  * Bump version to 2.13.2 (#21133)
  * fix: add missing fields in listrepositories (#20991) (#21129)
  * fix: Allow to delete repos with invalid urls (#20921) (#20975)
    (#21116)
  * fix: 20791 - sync multi-source application out of order source
    syncs (cherry-pick #21071) (#21077)
  * fix: Bitbucket Cloud PR Author is processed correctly (#20769)
    (#20990) (#21039)
  * fix: API server should not attempt to read secrets in all
    namespaces (#20950) (#20960)
  * fix: Memory leak in repo-server (#20876) (#20894)
  * chore(deps): bump http-proxy-middleware from 2.0.4 to 2.0.7 in
    /ui (#20518) (#20892)
  * fix(cli): Fix appset generate in --core mode (#20717) (#20883)
* Thu Nov 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.13.1:
  * Bump version to 2.13.1 (#20865)
  * fix: Fix repeated 403 due to app namespace being undefined
    (#20699) (#20819) (#20860)
  * feat: option to disable writing k8s events(#18205) (#18441)
    (#20788)
  * fix: disable automaxprocs logging (#20069) - cherry-pick 2.13
    (#20718)
  * chore: Don't degrade PDB on InsufficientPods (#20171) (#20665)
    (#20694)
  * fix(pkce): 20202 Backport PKCE auth flow fix for basehref and
    reauth (#20675)
  * fix: check for source position when --show-params is set
    (#20682) (#20689)
* Mon Nov  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.13.0:
  Large update, please find the full changelog here:
  https://build.opensuse.org/request/show/1220445
  * Bump version to 2.13.0 (#20652)
  * feat(cli): ignore tracking annotation on backup restore
    (#18960)
  * fix(cli): `admin settings rbac can` has inconsistency among
    project resources (#17805)
  * fix: notifications triggered from CLI fails for repo functions
    (#19213)
  * fix(cli): add optional password setting for headless redis
    client (#19035) (#19039)
  * fix(cli): Get Redis password from secret in `loadClusters()`
    (#18951)
  * fix(cli): skip printing summary when output mode is set to
    json/yaml (issue: #18620) (#18797)
  * test(cli): unstable unit test caused by unsorted array (#18722)
  * feat(cli): add cmd to preview generated apps of appsets
    (#10895) (#16781)
* Fri Oct 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.12.6:
  * Bump version to 2.12.6 (#20455)
  * fix: don't disable buttons for multi-source apps (#20446)
    (#20448)
  * fix(diff): avoid cache miss in server-side diff (#20423)
    (#20424) (#20450)
* Fri Oct 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.12.5:
  * fix(cli): cherrypick Redis password fix #19599 into 2.12
    (#20262)
* Fri Sep 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.12.4:
  * Bump version to 2.12.4 (#20115)
  * fix: CVE-2024-45296 Backtracking regular expressions cause
    ReDoS by upgrading path-to-regexp from 1.8.0 to 1.9.0 (#20087)
    (#20090)
  * cherry-pick chore(deps-dev): bump webpack from 5.84.1 to 5.94.0
    in /ui (#20056)
  * chore(deps): bump dompurify from 2.3.6 to 2.5.6 in /ui (#19955)
    (#20016)
  * fix(appset): Fix perpetual appset reconciliation (#19822)
    (#19995)
  * chore(deps): bump express from 4.19.2 to 4.20.0 in /ui (#19883)
    (#19987)
  * fix: diffing should not fail if resource fail schema validation
    (#19714) (#19729)
  * docs: note cluster scoping changes in 2.12x (#19684) (#19702)
* Tue Sep 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.12.3:
  * Bump version to 2.12.3 (#19694)
  * fix(AnyNameSpaceRegex): Additional Functions Glob to Regexexp
    (#19516) (#19665)
  * feat(sourceNamespace): Regex Support (#19016) (#19017) (#19664)
* Tue Sep 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.12.2:
  * Bump version to 2.12.2 (#19657)
  * fix(appset): remove cache references (#19652)
  * fix(appset): informer is not a kubernetes informer (#18905)
    (#19618) (#19636)
  * fix: Floating title content incorrect for multi-sources
    (#17274) (#19623) (#19627)
  * fix: Parse hostname correctly from repoURL to fetch correct CA
    cert (#19488) (#19602)
* Fri Aug 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.12.1:
  * Bump version to 2.12.1 (#19568)
  * fix(appset): cherry-pick - fix appset-in-any-namespace issue
    with git generators (#19558)
  * fix: appset gpg limitation for templated project fields
    (#19492) (#19534)
  * fix(appset): missing permissions for cluster install (#19059)
    (#19430) (#19435)
  * fix: docs version regex changed (#18756) (#19352)
* Tue Aug  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.12.0:
  large update, please see
  https://github.com/argoproj/argo-cd/releases/tag/v2.12.0
  no apparent CLI-related changes
* Wed Jul 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.7:
  * Bump version to 2.11.7 (#19175)
  * Merge commit from fork
* Mon Jul 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.6:
  * Bump version to 2.11.6 (#19142)
  * Merge commit from fork
  * fix: cherry-pick #18761 (v2.11) (#19108)
* Tue Jul 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.5:
  * Bump version to 2.11.5 (#19061)
  * chore: update gitops-engine (2.11) (#19036)
  * fix(cli): Get Redis password from secret in `loadClusters()`
    (#18951) (#18956)
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.4:
  * remove unwanted updating of source-position in app set command
    (#18887) (#18896)
  * Bump version to 2.11.4 (#18894)
  * fix: update static schemas (#18889)
  * fix(controller): bad server-side diffs (#18213) (2.11) (#18868)
  * docs: Fix .path to .path.segments go template (#18872) (#18874)
  * fix(webhook): bitbucket and azure not triggering refresh
    (#18289) (#18765) (#18819)
  * fix(appset): revert "keep reconciling even when params error
    occurred" (#17062) (#18781)
  * fix: docs site version selector broken (#18378) (#18724)
  * fix: Update braces package to 3.0.3 (#18459) (#18663)
  * Revert "feat(server): log app Spec along with event (#16416)"
    (#18458) (#18639)
  * test: fix e2e tests after GHSA-3cqf-953p-h5cp (#18543) (#18641)
  * chore(deps): upgrade redis to 7.2.15-alpine (cherry-pick
    release-2.11) (#18640)
  * chore: bump go version to 1.21.10 (#18540)
* Fri Jun  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.3:
  * Bump version to 2.11.3 (#18520)
  * Merge pull request from GHSA-3cqf-953p-h5cp
  * Merge pull request from GHSA-87p9-x75h-p4j2
  * fix: app names with non-alphanumeric characters in position 63
    break syncs (issue #18237) (#18256) (#18439)
  * fix source ordering issue in manifest generation for
    multi-source app while using manifests and diff commands
    (#18395) (#18408)
* Thu May 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.2:
  * Bump version to 2.11.2 (#18384)
  * fix: remove Egress NetworkPolicy for argocd-redis and
    argocd-redis-ha-haproxy (#18367) (#18372)
  * fix: revert registry change (#18328)
  * fix(deps): upgrade otel dependency (#18285) (#18324)
  * docs: add v2.11 notes to upgrading page (#18333)
  * chore(ci): fix release notes (#18132) (#18330)
* Tue May 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.1:
  * Bump version to 2.11.1 (#18319)
  * Merge pull request from GHSA-9766-5277-j5hr
  * Merge pull request from GHSA-9766-5277-j5hr
  * fix: UI MultiSource - Helm Chart with values.yaml (#18188)
    (#18200)
  * fix: copy visited map #11699 (#12667) (#18219)
  * update resolveRevision to use the correct source for
    multi-source app (#18194) (#18202)
  * Fix logging hash with multiple sources (#18189) (#18193)
  * chore(deps): upgrade helm to 3.14.4 (#18255) (#18286)
  * chore(deps): cherry-pick bump protobuf #17788 (#18284)
  * chore: update gitops engine for force sync option (#5882) -
    2.11 (#18125)
* Wed May  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.11.0:
  Major Upgrade, please read the documentation:
  https://argo-cd.readthedocs.io/en/stable/operator-manual/upgrading/overview/
* Tue Apr 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.9:
  * Bump version to 2.10.9 (#18033)
  * fix: enable sha256 and sha512 for git ssh (#18028) (#18029)
* Fri Apr 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.8:
  * Bump version to 2.10.8 (#17990)
  * fix: codegen after security fix - 2.10 (#17985)
  * Merge pull request from GHSA-9m6p-x4h2-6frq
  * Merge pull request from GHSA-9m6p-x4h2-6frq
  * chore: upgrade redis to 7.0.15 (#17666)
  * fix: codegen and e2e tests in release-2.10 (#17844)
* Mon Apr 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.7:
  * fix: docker build fails due to "The repository
    'http://deb.debian.org/debian buster-backports Release' does
    not have a Release file."
  * Bump version to 2.10.7 (#17831)
  * Merge pull request from GHSA-2gvw-w6fj-7m3c
* Fri Apr  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.6:
  * Bump version to 2.10.6 (#17744)
  * fix(security): use Chainguard fork of git-urls (#17732)
    (#17735)
  * fix: fix calculating patch for respect ignore diff feature
    (#17693)
  * fix(ui): Fix color generation for pod name in logs viewer.
    Fixes #17704 (#17706) (#17710)
  * chore(deps): bump webpack-dev-middleware from 5.3.1 to 5.3.4 in
    /ui (#17598) (#17686)
* Sat Mar 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.5:
  * fix cosign (#17656)
  * Bump version to 2.10.5 (#17654)
  * Merge pull request from GHSA-jhwx-mhww-rgc3
  * fix: elements should be optional (#17424) (#17510)
* Mon Mar 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.4:
  * Bump version to 2.10.4 (#17557)
  * Merge pull request from GHSA-6v85-wr92-q4p7
  * Merge pull request from GHSA-2vgg-9h6w-m454
  * fix(notifications): Helm.GetParameterValueByName should take
    helm.parametes first (#17472) (#17512)
  * fix: registry argument to be only the host instead full URL
    (#17381) (#17534)
  * fix(ui): add confirmation box in resource summary delete action
    (#17485) (#17545)
  * chore(deps): upgrade helm to 3.14.3 (#17531) (#17533)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.3:
  * Bump version to 2.10.3 (#17513)
  * Merge pull request from GHSA-g623-jcgg-mhmm
  * Merge pull request from GHSA-jwv5-8mqv-g387
  * fix: multi-source app breaks application parameters UI (#16910)
    (#17033) (#17332)
  * fix!: disable rate limiting completely by default (#17355)
    (#17393)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.2:
  * chore(ci): free up disk space for goreleaser (#17373) (#17374)
  * Bump version to 2.10.2 (#17370)
  * fix(ui): The tiles in Applications List are too wide #17220
    (#17340) (#17351)
  * fix: The argocd server api-content-type flag does not allow
    empty content-type header (#17331) (#17346)
  * chore(deps): upgrade helm to 3.14.2 (#17330) (#17333)
  * Corrected certificate managment for OCI helm charts (#16656)
    (#17320)
  * chore(deps): upgrade helm to 3.14.1 (#17213) (#17216)
  * chore(deps): Upgrade aws-sdk-go to support eks pod identity
    (#17063) (#17225)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.1:
  * Bump version to 2.10.1 (#17211)
  * fix(controller): add missing workqueue metrics (#16315)
    (#17013) (#17209)
  * fix: infer correct shard in statefulset setup (#17124, #17016)
    (#17167) (#17204)
  * fix: stop initializing deployment informer if dynamic sharding
    is disabled (#17097) (#17202)
  * fix(kustomize): set build dir (#15057) #16229 #16652 (#16653)
    (#17129)
  * fix(manifests): applicationset-controller dir is not added to
    cluster-rbac/kustomization.yaml. (#16810) (#17120)
  * chore(manifests): add ClsuterRole/ClusterRoleBinding for
    applicationset controller. (#16699) (#17119)
* Wed Feb 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.10.0:
  * Known Issues
  - 2.10.0 has a major issue in application controller running in
    HA mode. A fix will be in 2.10.1.
  * Changes
  - feat(controller): add sync jitter(#14241) (#16820) (#16960)
  - feat(ui): add status panel extensions (#15780)
  - feat: Implement Server-Side Diff (#13663)
  - feat(ui): Show prompt when every resource requires pruning
    (#16603)
  - feat: PostDelete hook support (#16595)
  - feat(security): log user when access is blocked (#16558)
  - feat(ui): Add sourceNamespaces in Projects UI and only show
    it if AppsInAnyNamespaceEnabled flag is set (#16249)
  - feat(appset): Advanced Templating using templatePatch
    (#14893)
  - feat: Argocd notification self service (#16488)
  - feat(cli): Added example to admin-cluster.go and
    projectwindow.go files (#16128)
  - feat(server): log app Spec along with event (#16416)
  - feat(opentelemetry): ✨ support for secured OTLP endpoint and
    headers (#15573)
  - feat(oidc): optionally query OIDC UserInfo to gather group
    claims (#12062)
  - feat(app): Support app sync --dry-run --revision
    some-revision with arbitrary revisions(#12592) (#16387)
  - feat: add support for ALL_PROXY (#10451)
  - feat(appset): Added 'slugify' sprig function (#15188)
  - feat: Support for Kustomize Components (#16230)
  - feat: add retry logic for k8s client #7692 (#16154)
  - feat: grace period for repo errors to prevent aggressive
    unknown sync state (#16085)
  - feat: add examples to --help output for admin.go file
    (#16030)
  - feat: add examples to --help ouput for argocd_server.go file
    (#16032)
  - feat: Allow 'both' option for uibannerposition (#14623)
  - feat: PKCE authentication flow for web logins #9890 (#15889)
  - feat(cli): example for generate-allow-list (#16136)
  - feat(cli): Add examples to --help output for get KEYID
    (#16019)
  - feat(cli): Add examples to --help output for "gpg_list"
    (#16017)
  - feat: Add examples to --help output for remaining "create
    PROJECT ROLE-NAME" (#15983)
  - feat(cli): Add examples to argocd proj role cli family
    (#15875)
  - feat(cli): add admin-app-example (#15690) (#15861)
  - feat(cli): add project flag to avoid permission denied errors
    on 404 (#16040)
  - feat: expose notification secrets for request payload
    templating (#16055)
  - feat: make git requests configurable (#15646)
  - feat: add write back to application informer (#15987)
  - feat(cli): Add examples to --help output for "list PROJECT"
    (#16033)
  - feat(cli): Add examples to --help output for "gpg add"
    (#16020)
  - feat(ui): Recursive Helm Values files detection (#15935)
    (#15936)
  - feat: use rate limited queue (#15480)
  - feat: Add examples to --help output for remaining "get
    APPNAME" (#15862)
  - feat(cli): add the repocred-list-example (#15690) (#15869)
  - feat(cli): add the cluster-list-example (#15690) (#15866)
  - feat: Add examples to --help output for "delete PROJECT
    ROLE-NAME" (#15986)
  - feat(cli): Add examples to projectwindows.go (#15860)
  - feat(health): add iammanager.keikoproj.io/Iamrole health
    check (#15899)
  - feat: Add examples to --help output for "generate-spec
    PROJECT" (#15871)
  - feat(cli): add the repo-example (#15690) (#15865)
  - feat(cli): Add examples to --help output for "set APPNAME"
    (#15872)
  - feat(cli): Add examples to --help output for "logs APPNAME"
    (#15873)
  - feat(cli): Add example to argocd relogin command (#15839)
  - feat: Add examples to --help output for all "argocd proj"
    cmds (#15824)
  - feat(cli): Added example to --help output for bcrypt (#15838)
  - feat(cli): Add example to --help output for app actions
    (#15822)
  - feat(cli): Add examples to --help output for remaining
    "argocd account" (#15814)
  - feat(cli): Add examples to --help output for remaining
    "argocd repocreds" cmds (#15846)
  - feat(cli): Add example to --help output 1 (#15782)
  - feat(cli): Added example to --help output for context
    (#15809)
  - feat(ci): retry individual e2e tests (#15696)
  * Bug fixes (47)
  - fix(ci): correct helm checksum path (#17081) (#17083)
  - fix(controller): fix application controller deployment
    crashing (#16984) (#17093)
  - fix(server): allow disabling content-type check (#16959)
    (#16976)
  - fix(appcontroller): Uptake fix in gitops engine which fixes
    application sync with auto create ns and server side apply
    (#16942) (#16963)
  - fix: Use the cache for sharding (#15237) (#16902)
  - fix: enforce content type header for API requests (#16860)
    (#16877)
  - fix(appset): Use case insensitive comparison of repo details
    in appset webhook handler (#16503) (#16504)
  - fix(cli): argocd admin settings resource-overrides health to
    not ignore wildard customizations (#16461)
  - fix(repo-server): excess git requests, short-circuit
    GenerateManifests ref only (#16501)
  - fix(appset): Always remove ownerReferences when appset policy
    doesn't allow app's deletion (#12172) (#16506)
  - fix(ui): use background delete to match k8s terminology
    (#15579)
  - fix: Use math.MaxInt (instead of math.MaxInt64) to fix builds
    on 32bit platforms (#16065)
  - fix: cert-manager.io/certificate health.lua for consistent
    issuing (Issue #16523) (#16520)
  - fix(doc): Fix documentation templatePatch (#16522)
  - fix: Tooltips point in wrong direction#11935 (#12578)
  - fix(ui): add exec check to avoid API calls (#16168)
  - fix PerconaXtraDBCluster health (#16434)
  - fix(controller): Address diff cache miss issues (#16458)
  - fix(cli): pass redis compression to cluster stats and shards
    commands (#16060) (#16421)
  - fix: upgrade notifications-engine (#16354)
  - fix(ui): User Info blob is too far to the right relative to
    Applications/Settings/Documentation (#12016)
  - fix: fixed cli admin dashboard cmd (#16430)
  - fix(appset): use topics for Gitlab SCM Provider (#13169)
    (#13170)
  - fix(appset): prevent app deletion according to appset policy
    (#12172) (#15903)
  - fix: failing lint and unit test (#16275)
  - fix(appset): Fix name conflict in appset controller (#16207)
    (#16222)
  - fix(ui): summary: fix sync options block layout (#16152)
  - fix api docs (#16186)
  - fix(ui): Improve apps tiles view (#16140)
  - fix(appset): ignoreApplicationDifferences not working
    (#15965)
  - fix: rbac validate command can now take either namespace or
    policy-file (#15543)
  - fix: Add timezone to projectwindows list (#15929)
  - fix(banzai/KafkaCluster): Update health.lua (#15962)
  - fix(docs): proj role list example (#16074)
  - fix: list manually provided external urls before generated
    ones (#13296)
  - fix: Add ENV variable to configure GRPC Keep Alive Time
    (#15656) (#15806)
  - fix: delete event cache deadlock test flakiness (#15964)
  - fix(ci): unstable integration test (#15976)
  - fix: update docs for ApplicationService.Get to reflect
    reality (#15927)
  - fix: Replace antonmedv/expr with expr-lang/expr (#15879)
  - fix(notifications): Allow notifications controller to notify
    on all namespaces (#15702)
  - fix(cli): Do not error out with no errors (#15688)
  - fix: codeowners syntax error (#15781)
  - fix(appset): add option to disable SCM providers entirely
    (#14246) (#15248)
  - fix(applicationset): git generator ignores empty files
    (#15661)
  - fix(ci): misplaced config option (#15698)
  - fix(ci): do not fail fast on e2e test failures (#15694)
  * Documentation (39)
  - docs(hooks): add postdelete to table (#17048) (#17051)
  - docs(kustomize): add components yaml example (#17043)
    (#17046)
  - docs(argocd-cm): add timeout.reconciliation.jitter example
    (#17044) (#17047)
  - docs(applicationset): explain impact of empty spec in
    templatePatch (#17042) (#17045)
  - docs: add context to configmap example (#16763) (#16764)
  - docs: configmap items are strings (#16737) (#16738)
  - docs: add documentation for the argocd cluster commands
    (#16555)
  - docs: update telepresence quickstart link (#16616)
  - docs: callout the need to restart pods to pickup service
    accounts (#16610)
  - docs: fix indentation for preserve file mode (#16598)
  - docs(monitoring): add new ServiceMonitors for redis, dex,
    notifications (#16534)
  - docs: fix broken link in secret-management.md (#16588)
  - docs: Add Kong Inc. as a user (#16582)
  - docs: Fix minor typo in Declarative Setup (#16550)
  - docs: fix kustomize patches example (#16353)
  - docs: Katie as Release Champion for 2.10 and Added a column
    for Release Approver (#16341)
  - docs: update release doc and issue template (#16329)
  - docs: fix upgrade instructions (#16326)
  - docs: Add @gdsoumya to approvers in OWNERS (#16331)
  - docs: Document ApplyOutOfSyncOnly in application spec
    (#16282)
  - docs: add Axians ACSP to users (#16226)
  - docs: Ensure consistent proper case of Kubernetes (#16205)
  - docs: Add Semgrep as a user (#16185)
  - docs(cmp): Document ConfigManagementPlugin.spec.version more
    clearly (#15974)
  - docs(appset): ApplicationSets generators docs to use go
    templates (#16109) (#16127)
  - docs: added identity-center.md doc for AWS SSO (#15689)
  - docs(bounty): proposal for feature to hide anno...
* Sat Feb  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.6:
  * Bump version to 2.9.6 (#17078)
  * chore(deps): rm go-jose Cxb6dee8d5-b814 high vuln (#16947)
    (#16970) (#17056)
  * fix(redis): go-redis v9 regression missing metrics and
    reconnect hook (#13415) (#15275) (#17024)
  * fix(ui): Badge for apps in any namespace (#16739) (#17008)
  * fix(server): allow disabling content-type check (#16959)
    (#16977)
* Sat Jan 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.5:
  * Bump version to 2.9.5 (#16937)
  * fix(ui): set content-type for certain UI requests (#16923)
    (#16930) (#16933)
* Sat Jan 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.9.4:
  * Bump version to 2.9.4 (#16917)
  * chore(deps): bump github.com/go-git/go-git/v5 from 5.8.1 to
    5.11.0 (#16912)
  * fix: enforce content type header for API requests (#16860)
    (Cherry-pick release-2.9 ) (#16878)
  * fix: add list permission deployments (#16785) (#16804)
  * fix(ui):Fixed log horizontal scroll for issue #16411 (#16727)
    (#16761)
  * fix(action): Add missing owner refs and annotation to
    create-job action (#16607) (#16608)
  * Added missing 'alias:' prefix for repository name as described
    here: (#15902) (#16535)
  * fix(grpcproxy): add missing GRPCKeepAliveEnforcementMinimum
    (#15708) (#16576)
  * fix(appset): don't emit k8s events for unchanged apps, log at
    debug (#16562)
  * docs: Fix format issue in rbac.md (#16521) (#16538)
  * chore: upgrade k8s client from v0.24.2 to v0.24.17 (#16554)
  * fix(appset): Don't use revision cache when reconciling after
    webhook (#16062) (#16241) (#16536)
* Sun Dec  3 2023 kastl@b1-systems.de
- Update to version 2.9.3:
  * Bump version to 2.9.3 (#16510)
  * fix(repo-server): excess git requests, resolveReferencedSources
    and runManifestGenAsync not using cache (Issue #14725) (#16410)
    (#16494)
  * fix(controller): Address diff cache miss issues (#16458)
    (#16485)
  * fix: cherry-pick fixed cli admin dashboard cmd (#16457)
  * fix(ui): Issues with overlapping content in the app details
    view on smaller screens (#16268) (#16407)
* Tue Nov 21 2023 kastl@b1-systems.de
- Update to version 2.9.2:
  * Bump version to 2.9.2 (#16405)
  * feat: add support for ALL_PROXY (#10451) (#16401)
  * fix: set max for max cookie number to `math.MaxInt` (#16388)
    (#16397)
  * docs: fix documentation of ignoreApplicationDifferences
    (#16365) (#16380)
  * bump helm 3.13.2 (#16344)
  * fix: check for double definition (#16335)
  * docs: fix upgrade instructions (#16327)
* Fri Nov 17 2023 Johannes Kastl <kastl@b1-systems.de>
- new package argocd-cli: CLI for the ArgoCD declarative continuous
  deployment tool
